# Generated by Django 2.2.19 on 2021-04-21 13:56

import django.contrib.postgres.fields
from dateutil.rrule import DAILY, WEEKLY
from django.db import migrations, models


def migrate_recurrence_fields(apps, schema_editor):
    Event = apps.get_model('agendas', 'Event')

    for event in Event.objects.filter(recurrence_rule__isnull=False):
        if event.recurrence_rule['freq'] == DAILY:
            event.recurrence_days = list(range(7))
        elif event.recurrence_rule['freq'] == WEEKLY:
            event.recurrence_days = event.recurrence_rule['byweekday']
        event.recurrence_week_interval = event.recurrence_rule.get('interval', 1)
        event.save()


def reverse_migrate_recurrence_fields(apps, schema_editor):
    Event = apps.get_model('agendas', 'Event')

    for event in Event.objects.filter(recurrence_days__isnull=False):
        rrule = {}
        if event.recurrence_days == list(range(7)):
            event.repeat = 'daily'
            rrule['freq'] = DAILY
        else:
            rrule['freq'] = WEEKLY
            rrule['byweekday'] = event.recurrence_days
            if event.recurrence_days == list(range(5)):
                event.repeat = 'weekdays'
            elif event.recurrence_week_interval == 2:
                event.repeat = '2-weeks'
                rrule['interval'] = 2
            else:
                event.repeat = 'weekly'
        event.recurrence_rule = rrule
        event.save()


class Migration(migrations.Migration):

    dependencies = [
        ('agendas', '0090_default_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='recurrence_days',
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.IntegerField(
                    choices=[(0, 'Mo'), (1, 'Tu'), (2, 'We'), (3, 'Th'), (4, 'Fr'), (5, 'Sa'), (6, 'Su')]
                ),
                blank=True,
                null=True,
                size=None,
                verbose_name='Recurrence days',
            ),
        ),
        migrations.AddField(
            model_name='event',
            name='recurrence_week_interval',
            field=models.IntegerField(
                choices=[(1, 'Every week'), (2, 'Every two weeks'), (3, 'Every three weeks')],
                default=1,
                verbose_name='Repeat',
            ),
        ),
        migrations.RunPython(migrate_recurrence_fields, reverse_migrate_recurrence_fields),
        migrations.RemoveField(
            model_name='event',
            name='recurrence_rule',
        ),
        migrations.RemoveField(
            model_name='event',
            name='repeat',
        ),
    ]
